pagination

package
v0.1.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 8, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

templ: version: v0.3.977

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func PaginationCenterComponent

func PaginationCenterComponent(id string, url string, target string, page int, nbrPages int) templ.Component

func PaginationComponent

func PaginationComponent(id string, url string, target string, page int, nbrPages int) templ.Component

func PaginationLeftComponent

func PaginationLeftComponent(id string, url string, target string, page int, nbrPages int) templ.Component

func PaginationRightComponent

func PaginationRightComponent(id string, url string, target string, page int, nbrPages int) templ.Component

Types

This section is empty.

Jump to