Documentation
¶
Overview ¶
templ: version: v0.3.977
Index ¶
- func PaginationCenterComponent(id string, url string, target string, page int, nbrPages int) templ.Component
- func PaginationComponent(id string, url string, target string, page int, nbrPages int) templ.Component
- func PaginationLeftComponent(id string, url string, target string, page int, nbrPages int) templ.Component
- func PaginationRightComponent(id string, url string, target string, page int, nbrPages int) templ.Component
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PaginationComponent ¶
func PaginationLeftComponent ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.